| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.AppsLicensing.Licensing.LicenseAssignments.Insert
Contents
Description
Assign a license.
See: Enterprise License Manager API Reference for licensing.licenseAssignments.insert.
Synopsis
- type LicensingLicenseAssignmentsInsertResource = "apps" :> ("licensing" :> ("v1" :> ("product" :> (Capture "productId" Text :> ("sku" :> (Capture "skuId" Text :> ("user" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] LicenseAssignmentInsert :> Post '[JSON] LicenseAssignment))))))))))))))
- data LicensingLicenseAssignmentsInsert = LicensingLicenseAssignmentsInsert {}
- newLicensingLicenseAssignmentsInsert :: LicenseAssignmentInsert -> Text -> Text -> LicensingLicenseAssignmentsInsert
Resource
type LicensingLicenseAssignmentsInsertResource = "apps" :> ("licensing" :> ("v1" :> ("product" :> (Capture "productId" Text :> ("sku" :> (Capture "skuId" Text :> ("user" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] LicenseAssignmentInsert :> Post '[JSON] LicenseAssignment)))))))))))))) Source #
A resource alias for licensing.licenseAssignments.insert method which the
LicensingLicenseAssignmentsInsert request conforms to.
Constructing a Request
data LicensingLicenseAssignmentsInsert Source #
Assign a license.
See: newLicensingLicenseAssignmentsInsert smart constructor.
Constructors
| LicensingLicenseAssignmentsInsert | |
Fields
| |
Instances
newLicensingLicenseAssignmentsInsert Source #
Arguments
| :: LicenseAssignmentInsert | Multipart request metadata. See |
| -> Text | A product's unique identifier. For more information about products in this version of the API, see Products and SKUs. See |
| -> Text | A product SKU's unique identifier. For more information about available SKUs in this version of the API, see Products and SKUs. See |
| -> LicensingLicenseAssignmentsInsert |
Creates a value of LicensingLicenseAssignmentsInsert with the minimum fields required to make a request.